==> Rcmdr_0.9-4.tar.gz: Rcmdr/man/linearModel.Rd <==
\name{linearModel}
\alias{linearModel}

\title{Rcmdr Linear Model Dialog}
\description{
  This dialog is used to specify a linear model to be fit by the \code{\link[base]{lm}} function.
}

\details{
Enter a name for the linear model to be fit if you want to retain more than one model. The model 
name must be a valid R object name (consisting only of upper and lower-case letters, numerals, and
periods, and not starting with a numeral).

The variable-list box is there only to remind you of the names of variables in the active data set.
Factors are indicated in the variable list; all other variables are numeric.

The left model-formula box specifies the response variable to be used in the model; it
may be a variable name or an expression evaluating to the response variable, such as
\code{log(income)}.

The right model-formula box specifies the right-hand (i.e., predictor) side of the model.
See \code{\link[base]{lm}} for details.

You can type directly in the model formula boxes. Alternatively, double-clicking the left mouse
button on a variable in the variable-list transfers it to the left-hand side of the model (if
it is empty) or to the right-hand side. You can also enter operators and parentheses using the buttons
above the formula.

Specifying a subset expression allows you to fit the model to a subset of observations
in the active data set. For example, assuming that \code{gender} is a variable in the
active data set, entering \code{gender == "Male"} would restrict the model to males.

If the active model is a linear model and the active data set has not changed, 
then the initial values of the left-hand-side,
right-hand-side, and subset fields are retained from the previous model.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[base]{lm}}, \code{\link[base]{Comparison}}}

\keyword{models}

==> Rcmdr_1.5-2.tar.gz: Rcmdr/man/linearModel.Rd <==
\name{linearModel}
\alias{linearModel}

\title{Rcmdr Linear Model Dialog}
\description{
  This dialog is used to specify a linear model to be fit by the \code{\link[stats]{lm}} function.
}

\details{
The left model-formula box specifies the response variable to be used in the model; it
may be a variable name or an expression evaluating to the response variable, such as
\code{log(income)}.

The right model-formula box specifies the right-hand (i.e., predictor) side of the model.
See \code{\link[stats]{lm}} for details.

You can type directly in the model formula boxes. Alternatively, double-clicking the left mouse
button on a variable in the variable-list transfers it to the left-hand side of the model (if
it is empty) or to the right-hand side. You can also enter operators and parentheses using the buttons
above the formula. If you select several variables in the variable-list box, clicking on the
\code{+}, \code{*}, or \code{:} button will enter them into the model formula.

Specifying a subset expression allows you to fit the model to a subset of observations
in the active data set. For example, assuming that \code{gender} is a variable in the
active data set, entering \code{gender == "Male"} would restrict the model to males.

If the active model is a linear model and the active data set has not changed, 
then the initial values of the left-hand-side,
right-hand-side, and subset fields are retained from the previous model.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link[stats]{lm}}, \code{\link[base]{Comparison}}}

\keyword{models}
